from fastmcp import FastMCP

mcp: FastMCP = FastMCP(
    name="Unofficial Cellosaurus MCP",
    instructions="Unofficial MCP server for the SIB Cellosaurus resource.",
    on_duplicate_tools="error",
)
